**THIS IS A WORK IN PROGRESS, I AM JUST UPLOADING THIS AS A PLACEHOLDER FOR NOW**

# ezprez

*A generic python PyPi project template. Replace this line with a project description*

## TODO

- [ ] Fill out [quick start](#quick-start)
- [ ] Create the actual package code
- [ ] Fill out or remove the following sections
  - [ ] [Examples](#examples)
  - [ ] [Arguments](#arguments)
  - [ ] [Additional documentation](#additional-documentation)
- [ ] Fill out CONTRIBUTING.md
- [ ] Fill out CHANGELOG.md
- [ ] Create tests, see [creating tests](#creating-tests) if you have never made tests before
- [ ] Add deepsource

## Table of Contents
- [What does ezprez do?](#what-does-ezprez-do)
- [Features & Roadmap](#features--roadmap)
- [Why should I use ezprez?](#why-should-i-use-ezprez)
- [Who is ezprez for?](#who-is-ezprez-for)
- [Quick-start](#quick-start)
    - [Installation](#installation)
      - [From source](#from-source)
      - [From PyPi](#from-pypi)
      - [Examples](#examples)
- [Usage](#usage)
    - [Arguments](#arguments)
- [Additional Documentation](#additional-documentation)

## What does ezprez do?

Let's you write simple python scripts to generate web presentations

## Features & Roadmap

### Simple class based api

The api iteself uses native python classes to create presentations in a short script that's easily editable

### No web experience needed

Since this is a pure python API you can write web presentations without knowing HTML

### Backed on a reliable web framework

Webslides powers this project and is a well-tested and stable web framework.

## Why should I use ezprez?

Ezprez is the simplest API for writing web presentations without needing explicit knowledge of web development. If you are looking to create powerpoint style presentations [python-pptx](https://python-pptx.readthedocs.io/en/latest/) or [the google slides api](https://developers.google.com/slides/quickstart/python) is better suited for this job.

## Who is ezprez for?

- People who want an easy way to create web presentations without editing html
- People who know python but not web development technologies

## Quick-start

*Include how people can get started using your project in the shortest time possible*

### Installation

#### From source

1. Clone this repo: (put github/source code link here)
2. Run ```pip install .``` or ```sudo pip3 install .```in the root directory

#### From PyPi

1. Run ```pip install ezprez```

#### Examples

*Include an example or two of usage, or common use cases*

## Usage

*Include how to use your package as an API (if that's what you're going for)*

### Arguments

*If you are writing a script, include some helpful/often used arguments here. If you decide to use [docopt](http://docopt.org/) the usage string should do.* 

## Additional Documentation

*If you have any supplementary documentation elsewhere (i.e. https://readthedocs.org/) include references to it here.*
